@@ -1,77 +1,91 @@
+use warnings;
+use strict;
+
 package MooseX::Has::Sugar;
-our $VERSION = '0.0404';
+our $VERSION = '0.0405';
+
 
 
 # ABSTRACT: Sugar Syntax for moose 'has' fields
 
-use warnings;
-use strict;
 
 use Carp          ();
 use Sub::Exporter ();
 
+
 Sub::Exporter::setup_exporter(
-    {
-        as      => 'do_import',
-        exports => [ 'ro', 'rw', 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', 'bare', ],
-        groups  => {
-            isattrs => [ 'ro',       'rw',   'bare', ],
-            attrs   => [ 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', ],
-            allattrs => [ '-attrs', '-isattrs' ],
-            default  => [ '-attrs', '-isattrs' ],
-        }
+  {
+    as      => 'do_import',
+    exports => [ 'ro', 'rw', 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', 'bare', ],
+    groups  => {
+      isattrs => [ 'ro',       'rw',   'bare', ],
+      attrs   => [ 'required', 'lazy', 'lazy_build', 'coerce', 'weak_ref', 'auto_deref', ],
+      default => [ '-attrs', '-isattrs' ],
     }
+  }
 );
 
 sub import {
-    for (@_) {
-        if ( $_ =~ qr/^[:-]is$/ ) {
-            Carp::croak( "Trivial ro/rw with :is dropped as of 0.0300.\n" . " See MooseX::Has::Sugar::Minimal for those. " );
-        }
+  for (@_) {
+    if ( $_ =~ qr/^[:-]is\$/ ) {
+      Carp::croak( qq{Trivial ro/rw with :is dropped as of 0.0300.\n} . q{ See MooseX::Has::Sugar::Minimal for those. } );
     }
-    goto &MooseX::Has::Sugar::do_import;
+    if ( $_ =~ qr/^[:-]allattrs\$/ ) {
+      Carp::carp(q{MooseX::Has::Sugar->import(:allattrs) is deprecated. just do 'use MooseX::Has::Sugar;' instead.});
+      $_ =~ s/^[:-]allattrs\$/:default/;
+    }
+  }
+  goto &MooseX::Has::Sugar::do_import;
 }
 
+
 sub bare() {
-    return ( 'is', 'bare' );
+  return ( 'is', 'bare' );
 }
 
+
 sub ro() {
-    return ( 'is', 'ro' );
+  return ( 'is', 'ro' );
 }
 
+
 sub rw() {
-    return ( 'is', 'rw' );
+  return ( 'is', 'rw' );
 }
 
+
 sub required() {
-    return ( 'required', 1 );
+  return ( 'required', 1 );
 }
 
+
 sub lazy() {
-    return ( 'lazy', 1 );
+  return ( 'lazy', 1 );
 }
 
+
 sub lazy_build() {
-    return ( 'lazy_build', 1 );
+  return ( 'lazy_build', 1 );
 }
 
+
 sub weak_ref() {
-    return ( 'weak_ref', 1 );
+  return ( 'weak_ref', 1 );
 }
 
+
 sub coerce() {
-    return ( 'coerce', 1 );
+  return ( 'coerce', 1 );
 }
 
+
 sub auto_deref() {
-    return ( 'auto_deref', 1 );
+  return ( 'auto_deref', 1 );
 }
 1;
 
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -80,7 +94,7 @@ MooseX::Has::Sugar - Sugar Syntax for moose 'has' fields
 
 =head1 VERSION
 
-version 0.0404
+version 0.0405
 
 =head1 SYNOPSIS
 
@@ -102,7 +116,7 @@ and makes it take up less visual space, which makes it faster to read.
 
 =head3 No String Worries
 
-Strings are often problematic, due to whitespace etc. Noted that if you do
+Strings are often problematic, due to white-space etc. Noted that if you do
 happen to mess them up, Moose should at I<least> warn you that you've done
 something daft. Using this alleviates that worry.
 
@@ -124,7 +138,7 @@ something daft. Using this alleviates that worry.
 
 =head3 Lazy Evil way to do it:
 
-B<PLEASE DONT DO THIS>
+B<PLEASE DO NOT DO THIS>
 
     has qw( foo isa Str is ro required 1 );
     has qw( bar isa Str is rw lazy_build 1 );
@@ -194,58 +208,18 @@ Or even
             lazy_build,
     );
 
-=head1 EXPORT
-
-=over 4
-
-=item rw
-
-=item ro
-
-=item bare
-
-=item lazy
-
-=item lazy_build
-
-=item required
-
-=item coerce
-
-=item weak_ref
-
-=item auto_deref
-
-=back
-
 =head1 EXPORT GROUPS
 
-=over 4
-
-=item :default
+=head2 :default
 
 Since 0.0300, this exports all our syntax, the same as C<:attrs :isattrs>.
 Primarily because I found you generally want all the sugar, not just part of it.
 This also gets rid of that nasty exclusion logic.
 
-=item :is
-
-B<DEPRECATED>. See L<MooseX::Has::Sugar::Minimal> for the same functionality
-
-=item :attrs
-
-This exports C<lazy> , C<lazy_build> and C<required>, C<coerce>, C<weak_ref>
-and C<auto_deref> as subs that assume positive.
-
-    has foo => (
-            required,
-            isa => 'Str',
-    );
-
-=item :isattrs
+=head2 :isattrs
 
 This exports C<ro>, C<rw> and C<bare> as lists, so they behave as stand-alone attrs like
-C<lazy> does.
+L</lazy> does.
 
     has foo => (
             required,
@@ -253,97 +227,95 @@ C<lazy> does.
             ro,
     );
 
-B<NOTE: This option is incompatible with L<MooseX::Has::Sugar::Minimal>>
+B<NOTE: This option is incompatible with L<MooseX::Has::Sugar::Minimal>> : L</CONFLICTS>
 
-=item :allattrs
+=head2 :attrs
 
-This is  a shorthand for  qw( :isattrs :attrs )
+This exports L</lazy> , L</lazy_build> and L</required>, L</coerce>, L</weak_ref>
+and L</auto_deref> as subs that assume positive.
 
-=back
+    has foo => (
+            required,
+            isa => 'Str',
+    );
 
-=head1 FUNCTIONS
+B<NOTE: This option is incompatible with L<MooseX::Types> and L<Moose::Util::TypeConstraints>> : L</CONFLICTS>
 
-These you probably don't care about, they're all managed by L<Sub::Exporter>
-and its stuff anyway.
+=head2 :is
 
-=over 4
+B<DEPRECATED>. See L<MooseX::Has::Sugar::Minimal> for the same functionality
 
-=item rw
+=head2 :allattrs
 
-returns C<('is','rw')>
+B<DEPRECATED>, just use L</:default> or do
 
-=item ro
+    use MooseX::Has::Sugar;
 
-returns C<('is','ro')>
+=head1 EXPORTED FUNCTIONS
 
-=item bare
+=head2 bare
 
 returns C<('is','bare')>
 
-=item lazy
+=head2 ro
 
-returns C<('lazy',1)>
+returns C<('is','ro')>
 
-=item required
+=head2 rw
+
+returns C<('is','rw')>
+
+=head2 required
 
 returns C<('required',1)>
 
-=item lazy_build
+=head2 lazy
+
+returns C<('lazy',1)>
+
+=head2 lazy_build
 
 returns C<('lazy_build',1)>
 
-=item coerce
-
-returns C<('coerce',1)>
-
-=item weak_ref
+=head2 weak_ref
 
 returns C<('weak_ref',1)>
 
-=item auto_deref
+=head2 coerce
+
+returns C<('coerce',1)>
+
+B<WARNING:> Conflict with L<MooseX::Types> and L<Moose::Util::TypeConstraints>, see L<CONFLICTS>.
+
+=head2 auto_deref
 
 returns C<('auto_deref',1)>
 
-=back
+=head1 CONFLICTS
 
-=head1 BUGS
+=head2 MooseX::Has::Sugar::Minimal
 
-Please report any bugs or feature requests to
-C<bug-moosex-has-extras at rt.cpan.org>, or through
-the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-Has-Sugar>.  I will be
-notified, and then you'll automatically be notified of progress on your bug
-as I make changes.
+=head2 MooseX::Has::Sugar::Saccharin
 
-=head1 SUPPORT
+This module is not intended to be used in conjunction with
+ L<MooseX::Has::Sugar::Minimal> or L<MooseX::Has::Sugar::Saccharin>
 
-You can find documentation for this module with the perldoc command.
+We export many of the same symbols and its just not very sensible.
 
-    perldoc MooseX::Has::Sugar
+=head2 MooseX::Types
 
-You can also look for information at:
+=head2 Moose::Util::TypeConstraints
 
-=over 4
+due to exporting the L</coerce> symbol, using us in the same scope as a call to
 
-=item * RT: CPAN's request tracker
+    use MooseX::Types ....
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MooseX-Has-Sugar>
+or
+    use Moose::Util::TypeConstraints
 
-=item * AnnoCPAN: Annotated CPAN documentation
+will result in a symbol collision.
 
-L<http://annocpan.org/dist/MooseX-Has-Sugar>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/MooseX-Has-Sugar>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/MooseX-Has-Sugar/>
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
+We recommend using and creating proper type libraries instead, ( which will absolve you entirely of the need to use MooseX::Types and MooseX::Has::Sugar(::*)? in the same scope )
 
 =head1 AUTHOR
 
@@ -358,4 +330,3 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
